;****************************************************************************
;*																			*
;*						40 x 24 LCD Terminal / LCD Controller				*
;*																			*
;*								Version 1.1									*
;*																			*
;*								 by Benedikt								*
;*																			*
;*						Email:	benedikt83 t gmx.net						*
;*																			*
;****************************************************************************
;*																			*
;*	Die Software darf frei kopiert und verndert werden, solange sie nicht	*
;*	ohne meine Erlaubnis fr kommerzielle Zwecke eingesetzt wird.			*
;*																			*
;****************************************************************************
;*																			*
;*	Diese Software steuert ein 320x240 LCD an, und zeigt auf diesem 20 		*
;*	Zeilen Text mit je 40 zeichen an (8x12 Zeichensatz).					*
;*																		 	*
;****************************************************************************

.include "m8def.inc"

;Im Interrupt genutzte und genderte Register:
.def regsave	=r2
.def clockL		=r3
.def clockH		=r4
.def X_Cnt		=r5
.def CursorSave	=r6
.def blinkcount	=r7
.def YSaveL		=r10
.def YSaveH		=r11
.def WPos		=r12
.def RPos		=r13
.def XSaveL		=r14
.def XSaveH		=r15
.def tempi		=r16
.def tempi2		=r17
.def Y_Cnt		=r18
.def C_Cnt		=r19
.def flags		=r23
;zustzlich: X und Z

;Sonstige Register:
.def temp		=r20
.def temp2		=r21
.def RX			=r22
;zustzlich: Y

.equ CURSOR		=0
.equ DOBLINK	=1
.equ MEMIDLE	=2
.equ BLINKSTATE	=3
.equ BLINKCURSOR=4

;PortB
.equ 	CLOCK	=0					; Pixelclock
.equ 	PWM		=1					; PWM fr Contrast
.equ 	LP		=2					; Latch Puls (HSync)
.equ 	FRAME	=3					; First Line Marker (VSync)
.equ 	M		=4					; AC Drive
.equ 	ONOFF	=5					; LCD (VLCD) Enable

;Werte
.equ Baudrate	=57600				; Baudrate
.equ Framerate	=65					; Refreshrate
.equ F_CPU		=16000000			; CPU Freq
.equ RX_Buffer	=32					; UART Buffer
.equ CURSOR_CHAR=219				; ASCII Zeichen das als Cursor verwendet wird
.equ BlinkFreq	=221				; Blinkfrequenz (0-255) 

; Interne Konstanten
.equ HFREQ		=Framerate*240
.equ TDIV		=((F_CPU/8+(HFREQ)/2)/HFREQ)
.equ CSize		=12
.equ XSize		=40
.equ YSize		=240/CSize

.dseg
DDRAM:	.byte	XSize*YSize			; DDRAM
RXBUF:	.byte	RX_Buffer			; RX Buffer

;****************************************************************************
;	Interrupt Vektoren
;****************************************************************************

.cseg
.org 0
rjmp Reset

.org OC2addr
rjmp LCD_Line
	
.org URXCaddr
rjmp UART_RX_int


;****************************************************************************
;	CPU Register Initialisierung
;****************************************************************************

Reset:
	ldi	temp, low(RAMEND)
	out	SPL, temp					;setup stack pointer
	ldi	temp, high(RAMEND)
	out	SPH, temp					;setup stack pointer

	ser temp
	out DDRB, temp
	out DDRC, temp
	out PORTD, temp

	ldi temp, TDIV-1
	out OCR2, temp

	ldi temp, (1<<WGM10)|(1<<COM1A1)|(1<<COM1A0); 8bit PWM
	out TCCR1A, temp

	ldi temp, 1						; 62,5kHz PWM
	out TCCR1B, temp

	ldi temp, 128
	out OCR1AL, temp

	ldi temp, (1<<WGM21)|2			; CTC
	out TCCR2, temp

	ldi temp, (1<<OCIE2)			; Compare2 Interrupt: Beginn der Datenausgabe
	out TIMSK, temp

	ldi temp, 0
	out UBRRH, temp

	ldi temp, (F_CPU/16+Baudrate/2)/Baudrate-1;Baudrate berechnen und runden
	out UBRRL, temp
	ldi temp, (1<<RXEN)|(1<<RXCIE)	; RX aktivieren
	out UCSRB, temp 		


;****************************************************************************
;	Variablen Initialisierung
;****************************************************************************

	clr RPos
	clr WPos
	clr flags

	ldi YL, low(DDRAM)
	ldi YH, high(DDRAM)

	ldi temp, 32
	clrloop:
		st Y+, temp
		inc temp
		ldi temp2, high(XSize*YSize+DDRAM)
		cpi YL, low(XSize*YSize+DDRAM)
		cpc YH, temp2
		brne clrloop

	ldi XL, low(DDRAM)
	ldi XH, high(DDRAM)
	sei
	sbi PORTB, ONOFF

;****************************************************************************
;	Hauptprogramm
;****************************************************************************

Mainloop:
	rcall rxuart
	sbr flags, 1<<MEMIDLE
	rjmp Mainloop

rxuart:			;UART Daten verarbeiten
	rcall uart_getchar
	cbr flags, 1<<MEMIDLE
	cpi RX, 32
	brlo command
	sbrc flags, CURSOR
	st Y, CursorSave
	st Y+, RX	;Daten
	ldi temp, high(XSize*YSize+DDRAM)
	cpi YL, low(XSize*YSize+DDRAM)
	cpc YH, temp
	brlo skipwpreset
	ldi YL, low(DDRAM)
	ldi YH, high(DDRAM)
skipwpreset:
	sbrs flags, CURSOR
	ret
	ld CursorSave, Y
	ldi temp, CURSOR_CHAR
	st Y, temp
	ret

command:				;Befehle
	cpi RX, 1			;Home
	brne com1
	sbrc flags, CURSOR
	st Y, CursorSave
	ldi YL, low(DDRAM)
	ldi YH, high(DDRAM)
	sbrs flags, CURSOR
	ret
	ld CursorSave, Y
	ldi temp, CURSOR_CHAR
	st Y, temp
	ret
com1:
	cpi RX, 2			;Display aus
	brne com2
	cbi PORTB, ONOFF
	ret
com2:
	cpi RX, 3			;Display an
	brne com3
	sbi PORTB, ONOFF
	ret
com3:
	cpi RX, 4			;Cursor aus
	brne com4
	sbrc flags, CURSOR
	st Y, CursorSave
	cbr flags, (1<<CURSOR)|(1<<BLINKCURSOR)
	ret
com4:
	cpi RX, 6			;Cursor an
	brne com6
	sbrs flags, CURSOR
	ld CursorSave, Y
	sbr flags, 1<<CURSOR
	cbr flags, (1<<BLINKCURSOR)
	ldi temp, CURSOR_CHAR
	st Y, temp
	ret
com6:
	cpi RX, 7			;Blinkender Cursor an
	brne com7
	sbrs flags, CURSOR
	ld CursorSave, Y
	sbr flags, (1<<CURSOR)|(1<<BLINKCURSOR)
	ldi temp, CURSOR_CHAR
	st Y, temp
	ret
com7:
	sbrc flags, CURSOR
	st Y, CursorSave
	cpi RX, 8			;Backspace
	brne com8
	sbrc flags, CURSOR
	st Y, CursorSave
	subi YL, 1
	sbci YH, 0
	ldi temp, high(DDRAM)
	cpi YL, low(DDRAM)
	cpc YH, temp
	brsh exbs
	ldi YL, low(DDRAM)
	ldi YH, high(DDRAM)
exbs:
	ldi temp, 32
	st Y, temp
	sbrs flags, CURSOR
	ret
	ld CursorSave, Y
	ldi temp, CURSOR_CHAR
	st Y, temp
	ret
com8:
	cpi RX, 10			;Line Feed
	brne com10
	sbrc flags, CURSOR
	st Y, CursorSave
	subi YL, low(-XSize)
	sbci YH, high(-XSize)
	ldi temp, high(XSize*YSize+DDRAM)
	cpi YL, low(XSize*YSize+DDRAM)
	cpc YH, temp
	brlo skipres
	ldi YL, low(DDRAM)
	ldi YH, high(DDRAM)
skipres:
	sbrs flags, CURSOR
	ret
	ld CursorSave, Y
	ldi temp, CURSOR_CHAR
	st Y, temp
	ret
com10:
	cpi RX, 11			;Delete in place
	brne com11
	ldi temp, 32
	st Y, temp
	sbrs flags, CURSOR
	ret
	ldi temp,32
	mov CursorSave, temp
	ldi temp, CURSOR_CHAR
	st Y, temp
	ret
com11:
	cpi RX, 12			;Clear all
	brne com12
	ldi YL, low(DDRAM)
	ldi YH, high(DDRAM)
	ldi temp, 32
	ldi temp2, high(XSize*YSize+DDRAM)
clrloop2:
	st Y+, temp
	cpi YL, low(XSize*YSize+DDRAM)
	cpc YH, temp2
	brne clrloop2
	ldi YL, low(DDRAM)
	ldi YH, high(DDRAM)
	sbrs flags, CURSOR
	ret
	ldi temp, 32
	mov CursorSave, temp
	ldi temp, CURSOR_CHAR
	st Y, temp
	ret
com12:
	cpi RX, 13			; CR
	brne com14
	sbrc flags, CURSOR
	st Y, CursorSave
	ldi temp, low(XSize*(YSize-1)+DDRAM)	; Anfang unterste Zeile
	ldi temp2, high(XSize*(YSize-1)+DDRAM)
crloop:
	cp YL, temp
	cpc YH, temp2
	brsh gotvalue		; Position an erster Stelle der aktuellen Zeile gefunden
	subi temp, low(XSize)
	sbci temp2, high(XSize)
	rjmp crloop
gotvalue:
	mov YL, temp
	mov YH, temp2
	sbrs flags, CURSOR
	ret
	ld CursorSave, Y
	ldi temp, CURSOR_CHAR
	st Y, temp
	ret
com14:
	cpi RX, 14			;Backlight
	brne com15
	rcall uart_getchar
	ret
com15:
	cpi RX, 15			;Contrast
	brne com16
	rcall uart_getchar
	cpi RX, 101
	brlo skiplimc
	ldi RX, 100
skiplimc:
	mov temp, RX
	lsl RX
	lsr temp
	add RX, temp
	out OCR1AL, RX
com16:
	cpi RX, 17			;Set Cursor
	brne com17
	sbrc flags, CURSOR
	st Y, CursorSave
	rcall uart_getchar
	mov temp, RX
	rcall uart_getchar
	ldi temp2, XSize
	mul RX, temp2
	mov YH, r1
	mov YL, r0
	subi YL, low(-DDRAM)	;Offset aufaddieren
	sbci YH, high(-DDRAM)
	add YL, temp			;Spalte aufaddieren
	ldi temp, 0
	adc YH, temp
	ldi temp, high(XSize*YSize+DDRAM)
	cpi YL, low(XSize*YSize+DDRAM)
	cpc YH, temp
	brlo skiprs
	ldi YL, low(DDRAM)
	ldi YH, high(DDRAM)
skiprs:
	sbrs flags, CURSOR
	ret
	ld CursorSave, Y
	ldi temp, CURSOR_CHAR
	st Y, temp
	ret
com17:
	cpi RX, 30			; Send direct
	brne com31
	sbrc flags, CURSOR
	st Y, CursorSave
	rcall uart_getchar
	rcall uart_getchar
	st Y+, RX	;Daten
	ldi temp, high(XSize*YSize+DDRAM)
	cpi YL, low(XSize*YSize+DDRAM)
	cpc YH, temp
	brlo skipwpreset2
	ldi YL, low(DDRAM)
	ldi YH, high(DDRAM)
skipwpreset2:
	sbrs flags, CURSOR
	ret
	ld CursorSave, Y
	ldi temp, CURSOR_CHAR
	st Y, temp
	ret
com31:
	ret

uart_getchar:
	cp WPos, RPos
	breq uart_getchar
	movw YSaveL, YL
	inc RPos
	mov RX, RPos
	andi RX, RX_Buffer-1
	mov RPos, RX
	clr RX
	ldi YL, low(RXBUF)
	ldi YH, high(RXBUF)
	add YL, RPos
	adc YH, RX
	ld RX, Y
	movw YL, YSaveL
	ret

UART_RX_int:
	in regsave, sreg
	in tempi, UDR
	inc WPos
	mov tempi2, WPos
	andi tempi2, RX_Buffer-1
	cp tempi2, RPos
	breq buffer_full
	mov WPos, tempi2
	clr tempi2
	ldi XL, low(RXBUF)
	ldi XH, high(RXBUF)
	add XL, WPos
	adc XH, tempi2
	st X, tempi
buffer_full:
	out sreg, regsave
reti

LCD_Line:					;Bildbeginn
	in regsave, sreg
	ldi tempi, XSize
	mov X_Cnt, tempi
	in tempi, PORTB
	cbr tempi, 1<<CLOCK
	mov clockL, tempi
	sbr tempi, 1<<CLOCK
	mov clockH, tempi
	movw XL, XSaveL
hloop:						; Loop fr 1 Zeile
	out PORTB, clockL		; PCLK L				1	-> 4 Takte H
	ld ZL, X+				; ASCII aus RAM lesen	2
	lpm tempi, Z			; Byte aus CGROM lesen	3
	out PORTB, clockH		; PCLK H				1	-> 4 Takte L
	out PORTC, tempi		; Low Nibble ausgeben	1
	out PORTB, clockL		; PCLK L				1	-> 2 Takte H
	swap tempi				; 						1
	out PORTC, tempi		; High Nibble ausgeben	1
	out PORTB, clockH		; PCLK H				1	-> 3 Takte L
	dec X_Cnt				;						1
	brne hloop				;						2
							;					  =15 Takte pro Byte
	out PORTB, clockL		; PCLK L

	sbi PORTB, LP
	dec C_Cnt				; Zhler fr Zeichenhhe erniedrigen
	nop
	nop
	cbi PORTB, LP
	cbi PORTB, FRAME
	breq skipcloop			; 1 Textzeile fertig ausgegeben ?
	inc ZH					; Nein -> Bilddatenadresse fr nchste Pixelzeile laden und
	sbiw XL, XSize			; Textadresse wieder an Anfang der Textzeile setzen
	rjmp exit_int

skipcloop:					; Alles fr neue Textzeile einrichten
	ldi ZH, 4				; 1024Bytes CGROM Offset
	ldi C_Cnt, CSize		; Zeichenhhen Counter laden
	inc Y_Cnt				; Zeilencounter erhhen
	cpi Y_Cnt, YSize		; Bildende ?
	brne exit_int

	sbis PORTB, M
	sbi PORTB, M
	sbic PINB, M
	cbi PORTB, M
	sbi PORTB, FRAME
	clr Y_Cnt
	ldi XL, low(DDRAM)
	ldi XH, high(DDRAM)
	dec blinkcount
	brne exit_int
	ldi tempi, 255-BlinkFreq
	mov blinkcount, tempi
	sbr flags, 1<<DOBLINK
exit_int:
	sbrs flags, BLINKCURSOR
	rjmp skipcursor
	sbrs flags, DOBLINK
	rjmp skipcursor
	sbrs flags, MEMIDLE
	rjmp skipcursor
	cbr flags, 1<<DOBLINK
	sbrs flags, BLINKSTATE
	st Y, CursorSave
	ldi tempi, CURSOR_CHAR
	sbrc flags, BLINKSTATE
	st Y, tempi
	ldi tempi, 1<<BLINKSTATE
	eor flags, tempi
skipcursor:
	movw XSaveL, XL
	out sreg, regsave
reti

;*** CG ROM Daten *** (8x10 Zeichensatz)

.org 512

.if (CSize==10)
font:
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	; 0x1F
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	; 0x3F
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	; 0x5F
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	; 0x7F
.db 0x00,0x00,0x80,0x80,0x00,0x01,0x81,0x00,0x80,0x00,0x01,0x00,0x01,0x01,0x41,0x80,0x40,0x00,0x00,0x81,0x00,0x01,0x80,0x01,0x00,0x41,0x41,0x00,0x00,0x00,0x00,0x00	; 0x9F
.db 0x80,0x80,0x80,0x80,0x41,0x41,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	; 0xBF
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x41,0xA0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x41,0x01,0x00,0x40,0x80,0x41,0x00,0x00,0x00,0x00,0x00,0x01,0xC7	; 0xDF
.db 0x80,0x00,0x81,0x01,0x41,0x41,0x00,0x00,0x00,0x40,0x80,0x01,0x80,0x40,0xC7,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	; 0xFF

.db 0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	; 0x1F
.db 0x00,0x80,0x41,0x41,0x40,0x00,0x01,0x80,0x80,0x01,0x81,0x00,0x00,0x00,0x00,0x80,0x81,0x80,0x81,0x81,0x80,0xC3,0x81,0xC3,0x81,0x81,0x00,0x00,0x00,0x00,0x00,0x81	; 0x3F
.db 0xC3,0x80,0xC7,0xE1,0xC7,0xE3,0xE3,0xE3,0xE7,0xC1,0xC1,0x67,0x07,0x3C,0x66,0xC3,0xC3,0xC3,0xC3,0xC1,0xC7,0x63,0x66,0x66,0x66,0x6C,0xC3,0x81,0x01,0x81,0x80,0x00	; 0x5F
.db 0x01,0x00,0x06,0x00,0xC0,0x00,0x80,0x00,0x06,0x80,0x80,0x06,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x01,0x00,0x00	; 0x7F
.db 0xE1,0x42,0x01,0x41,0x41,0x80,0x81,0x00,0x41,0x42,0x80,0x82,0x82,0x80,0x00,0x41,0x80,0x00,0xF1,0x42,0x42,0x80,0x01,0x80,0x82,0x00,0x00,0x00,0x81,0xE3,0x00,0x40	; 0x9F
.db 0x01,0x01,0x01,0x01,0x82,0x82,0x00,0x00,0x00,0x81,0x00,0x02,0x02,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x01,0x41,0x40,0x81,0x80,0x80,0x00,0x00,0x00,0x41,0x00	; 0xBF
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x82,0x41,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x42,0x03,0xC3,0x41,0x00,0x80,0x80,0x80,0x41,0x00,0x00,0x00,0x80,0x00,0x80,0x80,0x00	; 0xDF
.db 0x01,0x81,0x42,0x80,0x82,0x82,0x00,0x00,0x06,0x80,0x41,0x80,0x01,0x80,0x00,0x80,0x00,0x00,0x00,0x03,0xC0,0x81,0x00,0x00,0x00,0x00,0x00,0x00,0x81,0x81,0x80,0x00	; 0xFF

.db 0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	; 0x1F
.db 0x00,0x80,0x41,0x41,0xC1,0x26,0x82,0x80,0x01,0x80,0x81,0x00,0x00,0x00,0x00,0x80,0x42,0x81,0x42,0x42,0x81,0x02,0x02,0x42,0x42,0x42,0x00,0x00,0x00,0x00,0x00,0x42	; 0x3F
.db 0x24,0x80,0x22,0x22,0x22,0x21,0x21,0x24,0x42,0x80,0x80,0x42,0x02,0x66,0x43,0x24,0x21,0x24,0x21,0x42,0x45,0x22,0x24,0x24,0x42,0x44,0x42,0x01,0x01,0x80,0x41,0x00	; 0x5F
.db 0x80,0x00,0x02,0x00,0x40,0x00,0x01,0x00,0x02,0x00,0x00,0x02,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x01,0x41,0x80	; 0x7F
.db 0x22,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0xE3,0x00,0x92,0x00,0x00,0x00,0x00,0x00,0x00,0xC1,0x22,0x00,0x02,0x64,0x00,0x80	; 0x9F
.db 0x00,0x00,0x00,0x00,0x00,0x66,0x80,0x81,0x80,0x42,0x00,0x22,0x22,0x80,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x42,0x80,0x80,0x00,0x00,0x00,0x41,0x00	; 0xBF
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x81,0x03,0x21,0xE3,0xE3,0xE3,0x00,0xC1,0xC1,0xC1,0x00,0x00,0x80,0x00,0x80,0xC1,0x00	; 0xDF
.db 0xC3,0x42,0xC3,0xC3,0x00,0xC3,0x00,0x06,0xC3,0x22,0x22,0x22,0x00,0x63,0x00,0x01,0x00,0x00,0x00,0x21,0xC1,0x42,0x00,0x00,0x80,0x41,0x00,0x80,0x80,0x80,0x80,0x00	; 0xFF

.db 0x00,0x00,0x00,0x00,0x00,0xFF,0xFF,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	; 0x1F
.db 0x00,0x80,0x00,0xE3,0x22,0x46,0x61,0x00,0x01,0x80,0x00,0x00,0x00,0x00,0x00,0x80,0x42,0x80,0x40,0x40,0x81,0x83,0x02,0x80,0x42,0x42,0x80,0x80,0x80,0x00,0x02,0x40	; 0x3F
.db 0x99,0x41,0x22,0x02,0x22,0x01,0x01,0x04,0x42,0x80,0x80,0x82,0x02,0x66,0x43,0x24,0x21,0x24,0x21,0x02,0x01,0x22,0x42,0x24,0x81,0x82,0x80,0x01,0x01,0x80,0x00,0x00	; 0x5F
.db 0x00,0x81,0x83,0x81,0xC1,0x81,0x01,0xC1,0x82,0x80,0x80,0x82,0x80,0x2D,0x86,0x81,0x86,0xC1,0x80,0xC0,0x81,0x42,0x42,0x22,0x42,0x42,0xC1,0x80,0x80,0x01,0x82,0x80	; 0x7F
.db 0x02,0x42,0x81,0x81,0x81,0x81,0x81,0x81,0x81,0x81,0x81,0x01,0x01,0x80,0x80,0x80,0x21,0x63,0x82,0x81,0x81,0x81,0x42,0x42,0x42,0x22,0x22,0xE1,0x01,0xA4,0x42,0x80	; 0x9F
.db 0x81,0x01,0x81,0x42,0x83,0x43,0x81,0x81,0x00,0xA5,0x00,0x42,0x42,0x00,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0xA5,0x80,0x80,0x00,0x00,0x40,0x80,0x00	; 0xBF
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x81,0x80,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x81,0x80,0x21,0x21,0x21,0x21,0x80,0x80,0x80,0x80,0x00,0x00,0x80,0x00,0x80,0x80,0x00	; 0xDF
.db 0x24,0x42,0x24,0x24,0x81,0x24,0x00,0x83,0x22,0x22,0x22,0x22,0x42,0x41,0x00,0x00,0x00,0x80,0x00,0x43,0xC1,0x01,0x80,0x00,0x00,0x00,0x00,0x80,0x81,0x81,0x80,0x00	; 0xFF

.db 0x00,0x00,0x00,0x00,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	; 0x1F
.db 0x00,0x80,0x00,0x41,0x81,0x80,0xA2,0x00,0x01,0x80,0x00,0x80,0x00,0x00,0x00,0x80,0x42,0x80,0x80,0x80,0x82,0x40,0x83,0x80,0x81,0xC1,0x00,0x00,0x01,0x83,0x01,0x80	; 0x3F
.db 0x9A,0x41,0xC3,0x02,0x22,0xC1,0xC1,0xE4,0xC3,0x80,0x80,0x03,0x02,0xA5,0xC2,0x24,0xC1,0x24,0xC1,0x81,0x01,0x22,0x42,0xA5,0x81,0x01,0x01,0x01,0x01,0x80,0x00,0x00	; 0x5F
.db 0x00,0x40,0x42,0x42,0x42,0x42,0x81,0x42,0x43,0x80,0x80,0x03,0x80,0xD6,0x43,0x42,0x43,0x42,0x01,0x01,0x01,0x42,0x42,0xA2,0x42,0x42,0x40,0x80,0x80,0x01,0x00,0x80	; 0x7F
.db 0x02,0x42,0x42,0x40,0x40,0x40,0x40,0x42,0x42,0x42,0x42,0x01,0x01,0x80,0x41,0x41,0x01,0x90,0xE4,0x42,0x42,0x42,0x42,0x42,0x42,0x22,0x22,0x62,0x83,0xA4,0x81,0xC1	; 0x9F
.db 0x40,0x01,0x42,0x42,0x42,0x43,0x00,0x81,0x80,0x25,0x00,0x80,0x80,0x80,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x41,0x41,0x41,0xA5,0x80,0x80,0x80,0x80,0xC1,0xC1,0x80	; 0xBF
.db 0x80,0x00,0x00,0x80,0x00,0x80,0x40,0x41,0x80,0x80,0x00,0x00,0x80,0x00,0x80,0x42,0x81,0xA3,0x01,0x01,0x01,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x80,0x80,0x00	; 0xDF
.db 0x24,0xC3,0x24,0x24,0x42,0x24,0x82,0x42,0x22,0x22,0x22,0x22,0x42,0x41,0x00,0x00,0x00,0xC1,0x83,0x80,0xC0,0x82,0x00,0x00,0x00,0x00,0x80,0x80,0x00,0x00,0x80,0x00	; 0xFF

.db 0x00,0x00,0x00,0x00,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	; 0x1F
.db 0x00,0x80,0x00,0xE3,0x40,0x01,0x42,0x00,0x01,0x80,0x00,0xC1,0x00,0x81,0x00,0x01,0x42,0x80,0x01,0x40,0xC3,0x40,0x42,0x01,0x42,0x40,0x00,0x00,0x02,0x00,0x80,0x01	; 0x3F
.db 0x9A,0xE3,0x22,0x02,0x22,0x01,0x01,0x24,0x42,0x80,0x80,0x82,0x02,0xA5,0xC2,0x24,0x01,0x24,0x41,0x40,0x01,0x22,0x42,0xA5,0x81,0x01,0x02,0x01,0x80,0x80,0x00,0x00	; 0x5F
.db 0x00,0xC1,0x42,0x02,0x42,0xC3,0x01,0x42,0x42,0x80,0x80,0x03,0x80,0x94,0x42,0x42,0x42,0x42,0x01,0x80,0x01,0x42,0x42,0xA2,0x81,0x42,0x80,0x81,0x80,0x80,0x00,0x80	; 0x7F
.db 0x02,0x42,0xC3,0xC1,0xC1,0xC1,0xC1,0x02,0xC3,0xC3,0xC3,0x01,0x01,0x80,0x41,0x41,0xC1,0xF3,0x87,0x42,0x42,0x42,0x42,0x42,0x42,0x22,0x22,0xA2,0x01,0x25,0x81,0x80	; 0x9F
.db 0xC1,0x01,0x42,0x42,0x42,0xC2,0x81,0x00,0x80,0x42,0xC3,0x61,0x21,0x80,0x41,0x82,0x00,0x00,0x00,0x00,0x00,0x41,0x41,0x41,0x42,0x00,0x00,0xC1,0xC1,0x02,0x80,0xC1	; 0xBF
.db 0xC1,0x81,0x81,0xC1,0x81,0xC1,0xC1,0x41,0xC1,0xC1,0x81,0x81,0x00,0x81,0xC1,0x00,0x42,0x21,0xC1,0xC1,0xC1,0x80,0x80,0x80,0x80,0xC1,0xC1,0x00,0x00,0x00,0x80,0x00	; 0xDF
.db 0x24,0x22,0x24,0x24,0x42,0x24,0x82,0x42,0x22,0x22,0x22,0x22,0x42,0x80,0x00,0x00,0x80,0x80,0x00,0x21,0x40,0x41,0xC1,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	; 0xFF

.db 0x00,0x00,0x00,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	; 0x1F
.db 0x00,0x00,0x00,0x41,0x22,0x62,0x42,0x00,0x01,0x80,0x00,0x80,0x00,0x00,0x00,0x01,0x42,0x80,0x42,0x42,0x80,0x42,0x42,0x01,0x42,0x40,0x00,0x00,0x01,0x83,0x01,0x00	; 0x3F
.db 0x69,0x22,0x22,0x22,0x22,0x21,0x01,0x24,0x42,0x80,0x82,0x42,0x42,0x24,0x42,0x24,0x01,0x24,0x21,0x42,0x01,0x22,0x81,0x42,0x42,0x01,0x42,0x01,0x80,0x80,0x00,0x00	; 0x5F
.db 0x00,0x42,0x42,0x42,0x42,0x02,0x01,0xC2,0x42,0x80,0x80,0x82,0x80,0x94,0x42,0x42,0x42,0x42,0x01,0x40,0x01,0xC2,0x81,0x41,0x42,0x42,0x01,0x80,0x80,0x01,0x00,0x80	; 0x7F
.db 0x22,0xC2,0x02,0x42,0x42,0x42,0x42,0x42,0x02,0x02,0x02,0x01,0x01,0x80,0xC3,0xE3,0x01,0x84,0x98,0x42,0x42,0x42,0xC2,0xC2,0x42,0x22,0x22,0x23,0x02,0x26,0x42,0x80	; 0x9F
.db 0x42,0x01,0x42,0xC2,0x42,0xC2,0x00,0x00,0x01,0x81,0x40,0x22,0x62,0x80,0x82,0x41,0x80,0x80,0x80,0x80,0x80,0xE3,0xE3,0xE3,0x81,0x80,0x80,0x80,0x80,0x02,0xC1,0x80	; 0xBF
.db 0x80,0x00,0x00,0x80,0x00,0x80,0x42,0xE3,0x80,0x80,0x00,0x00,0x80,0x00,0x80,0x00,0x42,0x21,0x01,0x01,0x01,0x80,0x80,0x80,0x80,0x80,0x80,0x80,0x00,0x80,0x80,0x00	; 0xDF
.db 0x24,0x22,0x24,0x24,0x42,0x24,0x82,0x42,0xC3,0x22,0x22,0x22,0x42,0x80,0x00,0x00,0x00,0x00,0x83,0x62,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00	; 0xFF

.db 0x00,0x00,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	; 0x1F
.db 0x00,0x80,0x00,0x41,0xC1,0x64,0xA1,0x00,0x01,0x80,0x00,0x00,0x80,0x00,0x80,0x01,0x81,0x80,0xC3,0x81,0xC1,0x81,0x81,0x01,0x81,0x81,0x80,0x80,0x80,0x00,0x02,0x01	; 0x3F
.db 0x04,0x77,0xC7,0xC1,0xC7,0xE3,0x83,0xE3,0xE7,0xC1,0x03,0x67,0xC7,0x7E,0x47,0xC3,0x83,0xC3,0xA3,0x83,0x83,0xC1,0x81,0x42,0x66,0x83,0xC3,0x01,0x80,0x80,0x00,0x00	; 0x5F
.db 0x00,0xC1,0x81,0x81,0xC1,0x81,0x81,0x41,0x42,0x80,0x80,0xC2,0x80,0x94,0x42,0x81,0x83,0xC1,0x01,0x81,0x80,0x41,0x81,0x41,0x42,0x81,0xC1,0x80,0x80,0x01,0x00,0x80	; 0x7F
.db 0xC1,0x41,0x81,0xC1,0xC1,0xC1,0xC1,0x81,0x81,0x81,0x81,0x01,0x01,0x80,0x22,0x22,0x21,0x63,0xFC,0x81,0x81,0x81,0x41,0x41,0x81,0x22,0x22,0xC3,0xC3,0xC7,0x00,0x80	; 0x9F
.db 0xC1,0x01,0x81,0x41,0x42,0x42,0x00,0x00,0x02,0x00,0x00,0x60,0x20,0x80,0x41,0x82,0x80,0x80,0x80,0x80,0x80,0x22,0x22,0x22,0x00,0x80,0x80,0x00,0x00,0xC1,0x80,0x00	; 0xBF
.db 0x00,0x00,0x00,0x00,0x00,0x00,0xC1,0x22,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x81,0xC3,0x21,0x21,0x21,0x80,0x80,0x80,0x80,0x00,0x00,0x80,0x00,0x80,0x80,0x00	; 0xDF
.db 0x24,0xC2,0x24,0x24,0x81,0x24,0x43,0x83,0x06,0x22,0x22,0x22,0x81,0x80,0x00,0x00,0x00,0xC1,0x00,0x20,0x40,0x42,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00	; 0xFF

.db 0x00,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	; 0x1F
.db 0x00,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x80,0x00,0x00,0x80,0x00,0x00,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x00	; 0x3F
.db 0xC3,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x00,0x80,0x00,0x00	; 0x5F
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x00,0x02,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x80,0x80,0x01,0x00,0x80	; 0x7F
.db 0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x77,0x77,0xE3,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0xC1,0xC1,0x00,0x00,0x00,0x00,0x82	; 0x9F
.db 0x00,0x00,0x00,0x00,0x00,0x67,0x00,0x00,0x42,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x77,0x77,0x77,0x00,0x80,0x80,0x00,0x00,0x01,0x00,0x00	; 0xBF
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x77,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x00,0xE3,0xE3,0xE3,0x00,0xC1,0xC1,0xC1,0x00,0x00,0x80,0x00,0x80,0xC1,0x00	; 0xDF
.db 0xC3,0x00,0xC3,0xC3,0x00,0xC3,0x02,0x02,0x00,0xC1,0xC1,0xC1,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x81,0x00,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00	; 0xFF

.db 0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	; 0x1F
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	; 0x3F
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x81,0x00,0x81,0x00,0xC7	; 0x5F
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x81,0x00,0x00,0x01,0x00,0x00,0x00,0x00,0x00,0x07,0xC0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x00,0x80,0x00,0x01,0x00,0x00	; 0x7F
.db 0x81,0x00,0x00,0x00,0x00,0x00,0x00,0x81,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x01	; 0x9F
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x81,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x80,0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x00,0x80,0x80,0x00,0x00,0x00,0x00,0x00	; 0xBF
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0xC7,0x80,0x00,0x00	; 0xDF
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x07,0x00,0x00,0x00,0x00,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x81,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x00	; 0xFF
.endif

.if (CSize==12)
font:
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	; 0x1F
.db 0x00,0x00,0x00,0x00,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	; 0x3F
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x00	; 0x5F
.db 0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	; 0x7F
.db 0x00,0x00,0xC0,0x03,0x00,0x0C,0x83,0x00,0x03,0x00,0x0C,0x00,0x01,0x06,0x00,0x87,0xC0,0x00,0x00,0x03,0x00,0x0C,0x03,0x0C,0x00,0x00,0xCC,0x00,0xC3,0x00,0x00,0xE0	; 0x9F
.db 0xC0,0xC0,0xC0,0xC0,0x00,0x67,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x42,0x55,0xD6,0x81,0x81,0xC0,0x87,0x06,0x00,0x66,0x66,0x00,0x66,0x00,0xCC,0x00	; 0xBF
.db 0x81,0x81,0x00,0x81,0x00,0x81,0x00,0x67,0x66,0x00,0x66,0x00,0x66,0x00,0x66,0x00,0xCC,0x00,0x87,0x00,0x06,0x00,0x81,0x87,0x00,0x81,0x00,0xFF,0x00,0x00,0x06,0xFF	; 0xDF
.db 0x81,0x00,0x87,0x06,0x00,0x67,0x00,0x00,0x00,0x81,0x87,0x06,0x60,0x81,0x00,0xC0,0x00,0x00,0x00,0x0E,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	; 0xFF

.db 0x00,0xE7,0xE7,0x00,0x01,0x81,0x81,0x00,0x00,0x00,0x00,0xE3,0xC3,0x00,0xF7,0x00,0x08,0x20,0x81,0x66,0xF7,0xE7,0x00,0x81,0x81,0x81,0x00,0x00,0x00,0x00,0x00,0x00	; 0x1F
.db 0x00,0x03,0x66,0xC6,0x03,0x00,0x07,0x03,0xC0,0x06,0x00,0x00,0x00,0x00,0x00,0x00,0xC7,0x01,0x87,0x87,0xC0,0xCF,0x83,0xEF,0x87,0x87,0x00,0x00,0xC0,0x00,0x06,0x87	; 0x3F
.db 0xC7,0x03,0xCF,0xC3,0x8F,0xEF,0xEF,0xC3,0xCC,0x87,0xE1,0x6E,0x0F,0x6C,0x6C,0x83,0xCF,0x83,0xCF,0x87,0xCF,0xCC,0xCC,0x6C,0xCC,0xCC,0xEF,0xC3,0x00,0xC3,0x83,0x00	; 0x5F
.db 0x03,0x00,0x0E,0x00,0xC1,0x00,0x83,0x00,0x0E,0x81,0xC0,0x0E,0x87,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xC1,0x81,0x0E,0x37,0x00	; 0x7F
.db 0x87,0xCC,0x81,0x87,0xCC,0x06,0xC6,0x00,0x87,0xCC,0x06,0xC6,0x83,0x03,0xCC,0xCC,0x81,0x00,0xE3,0x87,0xCC,0x06,0x87,0x06,0x66,0xCC,0x00,0x00,0x66,0xA3,0x00,0xB1	; 0x9F
.db 0x81,0x81,0x81,0x81,0x67,0xCD,0x87,0x87,0x03,0x83,0x00,0x26,0x36,0x03,0x00,0x00,0x29,0xAA,0xBD,0x81,0x81,0x81,0xCC,0x03,0x83,0x66,0x66,0x00,0x66,0x03,0xCC,0x00	; 0xBF
.db 0x81,0x81,0x00,0x81,0x00,0x81,0x67,0xCD,0x66,0x00,0x66,0x00,0x66,0x00,0x66,0x00,0x03,0x8F,0xCC,0xCC,0x03,0x0F,0x03,0xCC,0xCC,0x81,0x00,0xFF,0x00,0x81,0x03,0xFF	; 0xDF
.db 0x03,0x87,0xCC,0x03,0x67,0xCD,0x00,0x00,0x0F,0x03,0xCC,0x03,0xC0,0x03,0xCF,0x81,0x00,0x00,0x00,0x33,0xF7,0xE7,0x00,0x00,0xC3,0xCC,0x00,0x03,0x87,0x87,0x00,0x00	; 0xFF

.db 0x00,0x3C,0xFF,0x44,0x83,0xC3,0xC3,0x00,0x00,0x00,0x00,0xE0,0x66,0x00,0x36,0x81,0x0C,0x60,0xC3,0x66,0xBD,0x36,0x00,0xC3,0xC3,0x81,0x00,0x00,0x00,0x00,0x01,0xEF	; 0x1F
.db 0x00,0x87,0x66,0xC6,0xC7,0x00,0x8D,0x03,0x81,0x03,0x00,0x00,0x00,0x00,0x00,0x20,0x6C,0x03,0xCC,0xCC,0xC1,0x0C,0x06,0x6C,0xCC,0xCC,0x00,0x00,0x81,0x00,0x03,0xCC	; 0x3F
.db 0x6C,0x87,0x66,0x66,0xC6,0x26,0x66,0x66,0xCC,0x03,0xC0,0x66,0x06,0xEE,0x6C,0xC6,0x66,0xC6,0x66,0xCC,0x4B,0xCC,0xCC,0x6C,0xCC,0xCC,0xEC,0x03,0x08,0xC0,0xC6,0x00	; 0x5F
.db 0x81,0x00,0x06,0x00,0xC0,0x00,0xC6,0x00,0x06,0x81,0xC0,0x06,0x81,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x81,0x03,0xAD,0x00	; 0x7F
.db 0xCC,0xCC,0x03,0xCC,0xCC,0x03,0xC6,0x00,0xCC,0xCC,0x03,0xC6,0xC6,0x81,0x00,0xCC,0x00,0x00,0x87,0xCC,0xCC,0x03,0xCC,0x03,0x66,0x00,0xCC,0x00,0x06,0xC6,0x00,0x81	; 0x9F
.db 0x03,0x03,0x03,0x03,0xCD,0x00,0xCC,0xCC,0x03,0x44,0x00,0x6E,0x6E,0x03,0x00,0x00,0x94,0x55,0x6B,0x81,0x81,0x00,0x00,0x00,0x44,0x66,0x66,0x00,0x66,0x03,0xCC,0x00	; 0xBF
.db 0x81,0x81,0x00,0x81,0x00,0x81,0xCD,0x00,0x66,0x00,0x66,0x00,0x66,0x00,0x66,0x00,0x8D,0xC6,0x00,0x00,0x00,0x03,0x00,0x00,0x00,0x81,0x00,0xFF,0x00,0x81,0x00,0xFF	; 0xDF
.db 0x00,0xCC,0x00,0x00,0xCD,0x00,0x00,0x0E,0x06,0x00,0x00,0x00,0x81,0x00,0x00,0x03,0x00,0x03,0x00,0x66,0xBD,0x36,0x03,0x00,0x66,0x00,0x00,0x07,0xC0,0xC0,0x00,0x00	; 0xFF

.db 0x00,0x18,0xFF,0xEE,0xC7,0xC3,0xE7,0x00,0x00,0x00,0x00,0xA3,0x66,0x00,0xF7,0xBD,0x0E,0xE0,0xE7,0x66,0xBD,0x03,0x00,0xE7,0xE7,0x81,0x81,0x03,0x00,0x42,0x01,0xEF	; 0x1F
.db 0x00,0x87,0x66,0xEF,0x0C,0x4C,0x8D,0x03,0x03,0x81,0x66,0x81,0x00,0x00,0x00,0x60,0xEC,0x0F,0xCC,0xC0,0xC3,0x0C,0x0C,0x6C,0xCC,0xCC,0x83,0x83,0x03,0x00,0x81,0xC0	; 0x3F
.db 0x6C,0xCC,0x66,0x6C,0x66,0x06,0x26,0x6C,0xCC,0x03,0xC0,0xC6,0x06,0xEF,0x6E,0x6C,0x66,0x6C,0x66,0xCC,0x03,0xCC,0xCC,0x6C,0xCC,0xCC,0x89,0x03,0x0C,0xC0,0x6C,0x00	; 0x5F
.db 0x00,0x00,0x06,0x00,0xC0,0x00,0x06,0x00,0x06,0x00,0x00,0x06,0x81,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x81,0x03,0xEC,0x01	; 0x7F
.db 0xCC,0x00,0x00,0x00,0x00,0x00,0x83,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x87,0xCF,0x00,0x8D,0x00,0x00,0x00,0x00,0x00,0x00,0x87,0xCC,0x00,0x06,0xEC,0x00,0x81	; 0x9F
.db 0x00,0x00,0x00,0x00,0x00,0x6C,0xCC,0xCC,0x00,0xAB,0x00,0xC6,0xC6,0x00,0x00,0x00,0x42,0xAA,0xD6,0x81,0x81,0x03,0x03,0x03,0xAB,0x66,0x66,0x00,0x66,0x87,0xCC,0x00	; 0xBF
.db 0x81,0x81,0x00,0x81,0x00,0x81,0x00,0x03,0x66,0x00,0x66,0x00,0x66,0x00,0x66,0x00,0xC0,0x66,0xCF,0xCF,0xCF,0x03,0x87,0x87,0x87,0x81,0x00,0xFF,0x00,0x81,0x87,0xFF	; 0xDF
.db 0x87,0xCC,0x87,0x87,0x00,0x87,0x00,0x06,0xC7,0xCC,0xCC,0xCC,0x00,0xCC,0x00,0x00,0x00,0x03,0x00,0xC3,0xBD,0x03,0x03,0x00,0x66,0x00,0x00,0x03,0x83,0x81,0xCF,0x00	; 0xFF

.db 0x00,0x5A,0xBD,0xEF,0xEF,0xFF,0xFF,0x00,0x00,0x00,0x00,0x27,0x66,0x00,0x36,0xE7,0x8F,0xE3,0x81,0x66,0xBD,0xC3,0x00,0x81,0x81,0x81,0xC0,0x06,0x0C,0x66,0x83,0xC7	; 0x1F
.db 0x00,0x87,0x42,0xC6,0x0C,0xCC,0x07,0x06,0x06,0xC0,0xC3,0x81,0x00,0x00,0x00,0xC0,0xED,0x03,0xC0,0xC0,0xC6,0x0C,0x0C,0x60,0xCC,0xCC,0x83,0x83,0x06,0xE7,0xC0,0x81	; 0x3F
.db 0xED,0xCC,0x66,0x0C,0x66,0x46,0x46,0x0C,0xCC,0x03,0xC0,0xC6,0x06,0xEF,0x6F,0x6C,0x66,0x6C,0x66,0x0C,0x03,0xCC,0xCC,0x6C,0x87,0xCC,0x81,0x03,0x06,0xC0,0x00,0x00	; 0x5F
.db 0x00,0x87,0xC7,0x87,0xC7,0x87,0x06,0x67,0xC6,0x87,0xC3,0x66,0x81,0xCF,0x8F,0x87,0xCD,0x67,0xCE,0x87,0xCF,0xCC,0xCC,0x6C,0x6C,0x66,0xCF,0x06,0x81,0x81,0x00,0x83	; 0x7F
.db 0x0C,0xCC,0x87,0x87,0x87,0x87,0x8F,0x87,0x87,0x87,0x87,0x87,0x87,0x87,0x87,0x87,0x4C,0xEF,0x8D,0x87,0x87,0x87,0xCC,0xCC,0x66,0xCC,0xCC,0x87,0x06,0x6D,0x00,0xE7	; 0x9F
.db 0x87,0x87,0x87,0xCC,0x8F,0x6E,0xE7,0x87,0x03,0xAA,0x00,0x87,0x87,0x03,0x33,0xCC,0x29,0x55,0xBD,0x81,0x81,0x87,0x87,0x87,0x2A,0x6E,0x66,0xEF,0x6E,0xCC,0x87,0x00	; 0xBF
.db 0x81,0x81,0x00,0x81,0x00,0x81,0x87,0x87,0x76,0xF7,0x7E,0xFF,0x76,0xFF,0x7E,0x00,0x60,0x66,0x4C,0x4C,0x4C,0x03,0x03,0x03,0x03,0x81,0x00,0xFF,0x00,0x81,0x03,0xFF	; 0xDF
.db 0xCC,0x8D,0xCC,0xCC,0x87,0xCC,0x66,0xC7,0x66,0xCC,0xCC,0xCC,0x66,0xCC,0x00,0x00,0x00,0xCF,0x00,0x8F,0xBD,0xC3,0x00,0x00,0x66,0x00,0x00,0x03,0xC0,0x03,0xCF,0x00	; 0xFF

.db 0x00,0x18,0xFF,0xEF,0xEF,0x7E,0xFF,0x00,0x00,0x00,0x00,0x8F,0xC3,0x00,0x36,0x7E,0xEF,0xEF,0x81,0x66,0xB7,0x66,0x00,0x81,0x81,0x81,0xEF,0xEF,0x0C,0xFF,0x83,0xC7	; 0x1F
.db 0x00,0x03,0x00,0xC6,0x87,0x81,0xAF,0x00,0x06,0xC0,0xFF,0xE7,0x00,0xEF,0x00,0x81,0x6D,0x03,0x81,0x83,0xCC,0x8F,0x8F,0xC0,0x87,0xC7,0x00,0x00,0x0C,0x00,0x60,0x03	; 0x3F
.db 0xED,0xCC,0xC7,0x0C,0x66,0xC7,0xC7,0x0C,0xCF,0x03,0xC0,0x87,0x06,0x6D,0xEF,0x6C,0xC7,0x6C,0xC7,0x07,0x03,0xCC,0xCC,0x6D,0x03,0x87,0x03,0x03,0x03,0xC0,0x00,0x00	; 0x5F
.db 0x00,0xC0,0x66,0xCC,0xCC,0xCC,0x8F,0xCC,0x67,0x81,0xC0,0xC6,0x81,0x6D,0xCC,0xCC,0x66,0xCC,0xE6,0xCC,0x06,0xCC,0xCC,0x6C,0xC6,0x66,0xC8,0x0C,0x00,0xC0,0x00,0xC6	; 0x7F
.db 0x0C,0xCC,0xCC,0xC0,0xC0,0xC0,0xC0,0xCC,0xCC,0xCC,0xCC,0x81,0x81,0x81,0xCC,0xCC,0x0C,0xB1,0xEF,0xCC,0xCC,0xCC,0xCC,0xCC,0x66,0xCC,0xCC,0xCC,0xCF,0x6D,0x6C,0x81	; 0x9F
.db 0xC0,0x81,0xCC,0xCC,0xCC,0x6F,0x00,0x00,0x06,0xAB,0xCF,0x03,0x73,0x03,0x66,0x66,0x94,0xAA,0x6B,0x81,0x8F,0xCC,0xCC,0xCC,0x2A,0x60,0x66,0x60,0x60,0x0C,0xCF,0x8F	; 0xBF
.db 0xF1,0xFF,0xFF,0xF1,0xFF,0xFF,0xC0,0xCC,0x06,0x06,0x00,0x00,0x06,0x00,0x00,0x6C,0xE7,0x6F,0x0C,0x0C,0x0C,0xCF,0x03,0x03,0x03,0x8F,0xF1,0xFF,0x00,0x00,0x03,0xFF	; 0xDF
.db 0xCC,0xCC,0xCC,0xCC,0xCC,0xCC,0x66,0x66,0x66,0xCC,0xCC,0xCC,0x66,0xCC,0x00,0x00,0xCF,0x03,0x8F,0x73,0xB7,0x66,0xCF,0x00,0xC3,0x00,0x81,0x87,0x87,0xC7,0xCF,0x00	; 0xFF

.db 0x00,0xDB,0x3C,0xEF,0xC7,0x7E,0xE7,0x00,0x00,0x00,0x00,0xCC,0x81,0x00,0x36,0x7E,0x8F,0xE3,0x81,0x00,0xB1,0x66,0x00,0x81,0x81,0x81,0xC0,0x06,0x0C,0x66,0xC7,0x83	; 0x1F
.db 0x00,0x03,0x00,0xC6,0xC0,0x03,0xED,0x00,0x06,0xC0,0xC3,0x81,0x00,0x00,0x00,0x03,0x6F,0x03,0x03,0xC0,0xEF,0xC0,0xCC,0x81,0xCC,0x81,0x00,0x00,0x06,0xE7,0xC0,0x03	; 0x3F
.db 0xED,0xCF,0x66,0x0C,0x66,0x46,0x46,0xEC,0xCC,0x03,0xCC,0xC6,0x26,0x6C,0xED,0x6C,0x06,0xEC,0xC6,0x81,0x03,0xCC,0xCC,0x6D,0x87,0x03,0x06,0x03,0x81,0xC0,0x00,0x00	; 0x5F
.db 0x00,0xC7,0x66,0x0C,0xCC,0xCF,0x06,0xCC,0x66,0x81,0xC0,0x87,0x81,0x6D,0xCC,0xCC,0x66,0xCC,0x67,0x06,0x06,0xCC,0xCC,0x6D,0x83,0x66,0x81,0x06,0x81,0x81,0x00,0x6C	; 0x7F
.db 0x0C,0xCC,0xCF,0xC7,0xC7,0xC7,0xC7,0x0C,0xCF,0xCF,0xCF,0x81,0x81,0x81,0xCC,0xCC,0x8F,0xF7,0x8D,0xCC,0xCC,0xCC,0xCC,0xCC,0x66,0xCC,0xCC,0xCD,0x06,0x6D,0xC6,0x81	; 0x9F
.db 0xC7,0x81,0xCC,0xCC,0xCC,0xED,0xEF,0xEF,0x0C,0x2B,0xC0,0xE6,0xF6,0x87,0xCC,0x33,0x42,0x55,0xD6,0x81,0x81,0xCC,0xCC,0xCC,0x2A,0x60,0x66,0x60,0x60,0x0C,0x03,0x81	; 0xBF
.db 0x00,0x00,0x81,0x81,0x00,0x81,0xC7,0xCC,0x06,0x06,0x00,0x00,0x06,0x00,0x00,0xC7,0x6C,0x66,0x8F,0x8F,0x8F,0x00,0x03,0x03,0x03,0x00,0x81,0xFF,0xFF,0x81,0x03,0x00	; 0xDF
.db 0xCC,0xCC,0xCC,0xCC,0xCC,0xCC,0x66,0x66,0x66,0xCC,0xCC,0xCC,0x66,0x87,0x00,0x00,0x00,0x03,0x00,0xF6,0xB1,0x66,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xCF,0x00	; 0xFF

.db 0x00,0x99,0x7E,0xC7,0x83,0x81,0x81,0x00,0x00,0x00,0x00,0xCC,0xE7,0x00,0x76,0xE7,0x0E,0xE0,0xE7,0x00,0xB1,0xC3,0xEF,0xE7,0x81,0xE7,0x81,0x03,0xEF,0x42,0xC7,0x83	; 0x1F
.db 0x00,0x00,0x00,0xEF,0xC0,0x06,0xCC,0x00,0x03,0x81,0x66,0x81,0x00,0x00,0x00,0x06,0x6E,0x03,0x06,0xC0,0xC0,0xC0,0xCC,0x03,0xCC,0x81,0x83,0x83,0x03,0x00,0x81,0x00	; 0x3F
.db 0x0C,0xCC,0x66,0x6C,0x66,0x06,0x06,0x6C,0xCC,0x03,0xCC,0xC6,0x66,0x6C,0xEC,0x6C,0x06,0xED,0x66,0xCC,0x03,0xCC,0xCC,0xC6,0xCC,0x03,0x26,0x03,0xC0,0xC0,0x00,0x00	; 0x5F
.db 0x00,0xCC,0x66,0x0C,0xCC,0x0C,0x06,0xCC,0x66,0x81,0xC0,0xC6,0x81,0x6D,0xCC,0xCC,0x66,0xCC,0x06,0x81,0x06,0xCC,0xCC,0x6D,0x83,0x66,0x06,0x03,0x81,0x03,0x00,0x6C	; 0x7F
.db 0xCC,0xCC,0x0C,0xCC,0xCC,0xCC,0xCC,0x0C,0x0C,0x0C,0x0C,0x81,0x81,0x81,0xCF,0xCF,0x0C,0x8D,0x8D,0xCC,0xCC,0xCC,0xCC,0xCC,0x66,0xCC,0xCC,0xCE,0x06,0x6E,0x83,0x81	; 0x9F
.db 0xCC,0x81,0xCC,0xCC,0xCC,0xEC,0x00,0x00,0x0C,0xAA,0xC0,0x3C,0xBD,0x87,0xCC,0x33,0x29,0xAA,0xBD,0x81,0x81,0xCF,0xCF,0xCF,0xAB,0x6E,0x66,0x6E,0xEF,0xCC,0xCF,0x81	; 0xBF
.db 0x00,0x00,0x81,0x81,0x00,0x81,0xCC,0xCF,0xF7,0x76,0xFF,0x7E,0x76,0xFF,0x7E,0xC6,0x6C,0x66,0x0C,0x0C,0x0C,0x00,0x03,0x03,0x03,0x00,0x81,0xFF,0xFF,0x81,0x03,0x00	; 0xDF
.db 0xCC,0xCC,0xCC,0xCC,0xCC,0xCC,0x66,0xC7,0xC7,0xCC,0xCC,0xCC,0x66,0x03,0x00,0x00,0x00,0x00,0x00,0xBD,0xB1,0xC3,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xCF,0x00	; 0xFF

.db 0x00,0x3C,0xFF,0x83,0x01,0x81,0x81,0x00,0x00,0x00,0x00,0xCC,0x81,0x00,0x7E,0xBD,0x0C,0x60,0xC3,0x66,0xB1,0xC0,0xEF,0xC3,0x81,0xC3,0x00,0x00,0x00,0x00,0xEF,0x01	; 0x1F
.db 0x00,0x03,0x00,0xC6,0x8F,0xCC,0xCD,0x00,0x81,0x03,0x00,0x00,0x83,0x00,0x83,0x0C,0x6C,0x03,0xCC,0xCC,0xC0,0xCC,0xCC,0x03,0xCC,0x03,0x83,0x83,0x81,0x00,0x03,0x03	; 0x3F
.db 0x0C,0xCC,0x66,0x66,0xC6,0x26,0x06,0x66,0xCC,0x03,0xCC,0x66,0x66,0x6C,0x6C,0xC6,0x06,0xC7,0x66,0xCC,0x03,0xCC,0x87,0xC6,0xCC,0x03,0x6C,0x03,0x60,0xC0,0x00,0x00	; 0x5F
.db 0x00,0xCC,0x66,0xCC,0xCC,0xCC,0x06,0xC7,0x66,0x81,0xC0,0x66,0x81,0x6D,0xCC,0xCC,0x66,0xCC,0x06,0xCC,0xC6,0xCC,0x87,0xC6,0xC6,0xC3,0x4C,0x03,0x81,0x03,0x00,0xEF	; 0x7F
.db 0xCC,0xCC,0xCC,0xCC,0xCC,0xCC,0xCC,0xCC,0x0C,0x0C,0x0C,0x81,0x81,0x81,0xCC,0xCC,0x4C,0x8D,0x8D,0xCC,0xCC,0xCC,0xCC,0xCC,0xC3,0xCC,0xCC,0xCC,0x0C,0xC6,0xC6,0x8D	; 0x9F
.db 0xCC,0x81,0xCC,0xCC,0xCC,0x6C,0x00,0x00,0xCC,0x44,0xC0,0x68,0x3B,0x87,0x66,0x66,0x94,0x55,0x6B,0x81,0x81,0xCC,0xCC,0xCC,0x44,0x66,0x66,0x66,0x00,0x87,0x03,0x81	; 0xBF
.db 0x00,0x00,0x81,0x81,0x00,0x81,0xCC,0xCC,0x00,0x66,0x00,0x66,0x66,0x00,0x66,0xC7,0x6C,0xC6,0x4C,0x4C,0x4C,0x00,0x03,0x03,0x03,0x00,0x81,0xFF,0xFF,0x81,0x03,0x00	; 0xDF
.db 0xCC,0x8F,0xCC,0xCC,0xCC,0xCC,0x66,0x06,0x06,0xCC,0xCC,0xCC,0xC3,0x03,0x00,0x00,0x00,0xCF,0x8F,0x3B,0xB1,0xC0,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xCF,0x00	; 0xFF

.db 0x00,0xE7,0xE7,0x01,0x00,0xE7,0xE7,0x00,0x00,0x00,0x00,0x87,0x81,0x00,0x6E,0x81,0x08,0x20,0x81,0x66,0xB1,0x6C,0xEF,0x81,0x81,0x81,0x00,0x00,0x00,0x00,0xEF,0x01	; 0x1F
.db 0x00,0x03,0x00,0xC6,0x03,0xC8,0x67,0x00,0xC0,0x06,0x00,0x00,0x83,0x00,0x83,0x08,0xC7,0xCF,0xCF,0x87,0xE1,0x87,0x87,0x03,0x87,0x07,0x00,0x81,0xC0,0x00,0x06,0x03	; 0x3F
.db 0xC7,0xCC,0xCF,0xC3,0x8F,0xEF,0x0F,0xE3,0xCC,0x87,0x87,0x6E,0xEF,0x6C,0x6C,0x83,0x0F,0xC0,0x6E,0x87,0x87,0x87,0x03,0xC6,0xCC,0x87,0xEF,0xC3,0x20,0xC3,0x00,0x00	; 0x5F
.db 0x00,0x67,0xCD,0x87,0x67,0x87,0x0F,0xC0,0x6E,0xE7,0xCC,0x6E,0xE7,0x6C,0xCC,0x87,0xC7,0xC7,0x0F,0x87,0x83,0x67,0x03,0xC6,0x6C,0xC0,0xCF,0xC1,0x81,0x0E,0x00,0x00	; 0x7F
.db 0x87,0x67,0x87,0x67,0x67,0x67,0x67,0x87,0xC7,0xC7,0xC7,0xE7,0xE7,0xE7,0xCC,0xCC,0xCF,0xFE,0xED,0x87,0x87,0x87,0x67,0x67,0xC0,0x87,0x87,0x87,0xEF,0x8B,0x6C,0x07	; 0x9F
.db 0x67,0xE7,0x87,0x67,0xCC,0x6C,0x00,0x00,0x87,0x83,0x00,0xC0,0xF3,0x03,0x33,0xCC,0x42,0xAA,0xD6,0x81,0x81,0xCC,0xCC,0xCC,0x83,0x66,0x66,0x66,0x00,0x03,0x03,0x81	; 0xBF
.db 0x00,0x00,0x81,0x81,0x00,0x81,0x67,0xCC,0x00,0x66,0x00,0x66,0x66,0x00,0x66,0x6C,0xC7,0x8F,0xCF,0xCF,0xCF,0x00,0x87,0x87,0x87,0x00,0x81,0xFF,0xFF,0x81,0x87,0x00	; 0xDF
.db 0x87,0x0C,0x87,0x87,0x87,0x87,0xB7,0x0F,0x0F,0x87,0x87,0x87,0xC0,0x87,0x00,0x00,0x00,0x00,0x00,0xF3,0xB1,0x6C,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	; 0xFF

.db 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0C,0x00,0x00,0x00,0x00,0x00,0x00,0xE7,0x00,0xE7,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	; 0x1F
.db 0x00,0x00,0x00,0x00,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x00,0x00,0x00,0x00	; 0x3F
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xE1,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFF	; 0x5F
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xCC,0x00,0x00,0xCC,0x00,0x00,0x00,0x00,0x00,0x06,0xC0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x81,0x00,0x00,0x00,0x00,0x00,0x00	; 0x7F
.db 0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x81,0x00,0x00,0x00,0x00,0x00,0x00,0x00	; 0x9F
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xF1,0x30,0x00,0x00,0x00,0x29,0x55,0xBD,0x81,0x81,0x00,0x00,0x00,0x00,0x66,0x66,0x66,0x00,0x03,0x00,0x81	; 0xBF
.db 0x00,0x00,0x81,0x81,0x00,0x81,0x00,0x00,0x00,0x66,0x00,0x66,0x66,0x00,0x66,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x81,0xFF,0xFF,0x00,0x00,0x00	; 0xDF
.db 0x00,0x06,0x00,0x00,0x00,0x00,0x06,0x00,0x00,0x00,0x00,0x00,0x81,0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x00,0xE7,0x00,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	; 0xFF

.db 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	; 0x1F
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	; 0x3F
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	; 0x5F
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x87,0x00,0x00,0x87,0x00,0x00,0x00,0x00,0x00,0x0F,0xE1,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0F,0x00,0x00,0x00,0x00,0x00,0x00	; 0x7F
.db 0x06,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0F,0x00,0x00,0x00,0x00,0x00,0x00,0x00	; 0x9F
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x94,0xAA,0x6B,0x81,0x81,0x00,0x00,0x00,0x00,0x66,0x66,0x66,0x00,0x00,0x00,0x81	; 0xBF
.db 0x00,0x00,0x81,0x81,0x00,0x81,0x00,0x00,0x00,0x66,0x00,0x66,0x66,0x00,0x66,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x81,0xFF,0xFF,0x00,0x00,0x00	; 0xDF
.db 0x00,0x00,0x00,0x00,0x00,0x00,0x0C,0x00,0x00,0x00,0x00,0x00,0x0F,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00	; 0xFF
.endif
